@@ -8,6 +8,7 @@ from subprocess import check_output
 import six
 import requests
 import logging
+import functools
 
 def get_token(request_uri: str = None):
     """Set valid service-account path to 'GOOGLE_APPLICATION_CREDENTIALS' envvar """
@@ -26,4 +27,10 @@ def get_token(request_uri: str = None):
         logger.debug(e)
         logger.warning("Continue without authentication")
 
-
+def fetch_mlflow_token(func):
+    """Refetch IAP ID Token before executing the func"""
+    @functools.wraps(func)
+    def wrapper_decorator(*args, **kwargs):
+        os.environ["MLFLOW_TRACKING_TOKEN"] = get_token(os.environ["MLFLOW_TRACKING_URI"])
+        return func(*args, **kwargs)
+    return wrapper_decorator
